@@ -1,5 +1,6 @@
 import datetime
 import json
+from enum import Enum, auto
 from uuid import uuid4
 
 from common import app_settings
@@ -15,8 +16,9 @@ from django.core.mail import EmailMultiAlternatives
 from django.http import HttpResponse
 from django.template import loader
 from django.utils import timezone
-from requests import post, get, put
+from requests import post, get, put, delete
 from requests.exceptions import RequestException
+from common.app_settings import domain
 
 NOTIFICATION_EMAIL = "Code For Life Notification <" + app_settings.EMAIL_ADDRESS + ">"
 VERIFICATION_EMAIL = "Code For Life Verification <" + app_settings.EMAIL_ADDRESS + ">"
@@ -26,24 +28,34 @@ PASSWORD_RESET_EMAIL = (
 INVITE_FROM = "Code For Life Invitation <" + app_settings.EMAIL_ADDRESS + ">"
 
 
+class DotmailerUserType(Enum):
+    TEACHER = auto()
+    STUDENT = auto()
+    NO_ACCOUNT = auto()
+
+
 def send_email(
     sender,
     recipients,
     subject,
     text_content,
+    title,
     html_content=None,
     plaintext_template="email.txt",
     html_template="email.html",
 ):
+
     # add in template for templates to message
 
     # setup templates
     plaintext = loader.get_template(plaintext_template)
     html = loader.get_template(html_template)
     plaintext_email_context = {"content": text_content}
-    html_email_context = {"content": text_content}
-    if html_content:
-        html_email_context = {"content": html_content}
+    html_email_context = {
+        "content": text_content,
+        "title": title,
+        "url_prefix": domain(),
+    }
 
     # render templates
     plaintext_body = plaintext.render(plaintext_email_context)
@@ -76,7 +88,11 @@ def send_verification_email(request, user, new_email=None):
 
         message = emailVerificationNeededEmail(request, verification.token)
         send_email(
-            VERIFICATION_EMAIL, [user.email], message["subject"], message["message"]
+            VERIFICATION_EMAIL,
+            [user.email],
+            message["subject"],
+            message["message"],
+            message["subject"],
         )
 
     else:  # verifying change of email address.
@@ -84,12 +100,20 @@ def send_verification_email(request, user, new_email=None):
 
         message = emailChangeVerificationEmail(request, verification.token)
         send_email(
-            VERIFICATION_EMAIL, [new_email], message["subject"], message["message"]
+            VERIFICATION_EMAIL,
+            [user.email],
+            message["subject"],
+            message["message"],
+            message["subject"],
         )
 
-        message = emailChangeNotificationEmail(request)
+        message = emailChangeNotificationEmail(request, new_email)
         send_email(
-            VERIFICATION_EMAIL, [user.email], message["subject"], message["message"]
+            VERIFICATION_EMAIL,
+            [user.email],
+            message["subject"],
+            message["message"],
+            message["subject"],
         )
 
 
@@ -99,10 +123,12 @@ def is_verified(user):
     return len(verifications) != 0
 
 
-def add_to_dotmailer(first_name: str, last_name: str, email: str):
+def add_to_dotmailer(
+    first_name: str, last_name: str, email: str, user_type: DotmailerUserType
+):
     try:
         create_contact(first_name, last_name, email)
-        add_contact_to_address_book(first_name, last_name, email)
+        add_contact_to_address_book(first_name, last_name, email, user_type)
     except RequestException:
         return HttpResponse(status=404)
 
@@ -140,8 +166,11 @@ def create_contact(first_name, last_name, email):
     )
 
 
-def add_contact_to_address_book(first_name, last_name, email):
-    url = app_settings.DOTMAILER_ADDRESS_BOOK_URL
+def add_contact_to_address_book(
+    first_name: str, last_name: str, email: str, user_type: DotmailerUserType
+):
+    main_address_book_url = app_settings.DOTMAILER_MAIN_ADDRESS_BOOK_URL
+
     body = {
         "email": email,
         "optInType": "VerifiedDouble",
@@ -154,11 +183,40 @@ def add_contact_to_address_book(first_name, last_name, email):
     }
 
     post(
-        url,
+        main_address_book_url,
         json=body,
         auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
     )
 
+    specific_address_book_url = app_settings.DOTMAILER_NO_ACCOUNT_ADDRESS_BOOK_URL
+
+    if user_type == DotmailerUserType.TEACHER:
+        specific_address_book_url = app_settings.DOTMAILER_TEACHER_ADDRESS_BOOK_URL
+    elif user_type == DotmailerUserType.STUDENT:
+        specific_address_book_url = app_settings.DOTMAILER_STUDENT_ADDRESS_BOOK_URL
+
+    post(
+        specific_address_book_url,
+        json=body,
+        auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
+    )
+
+
+def delete_contact(email: str):
+    try:
+        user = get_dotmailer_user_by_email(email)
+        user_id = user.get("id")
+        if user_id:
+            url = app_settings.DOTMAILER_DELETE_USER_BY_ID_URL.replace(
+                "ID", str(user_id)
+            )
+            delete(
+                url,
+                auth=(app_settings.DOTMAILER_USER, app_settings.DOTMAILER_PASSWORD),
+            )
+    except RequestException:
+        return HttpResponse(status=404)
+
 
 def get_dotmailer_user_by_email(email):
     url = app_settings.DOTMAILER_GET_USER_BY_EMAIL_URL.replace("EMAIL", email)
@@ -230,6 +288,7 @@ def update_email(user: Teacher or Student, request, data):
                 [user.new_user.email],
                 email_message["subject"],
                 email_message["message"],
+                email_message["subject"],
             )
         else:
             # new email to set and verify
