@@ -1,6 +1,5 @@
 import re
 from datetime import timedelta
-from enum import Enum
 from uuid import uuid4
 
 from django.contrib.auth.models import User
@@ -15,6 +14,12 @@ class UserProfile(models.Model):
 
     awaiting_email_verification = models.BooleanField(default=False)
 
+    # Holds the user's earned kurono badges. This information has to be on the UserProfile as the Avatar objects are
+    # deleted every time the Game gets deleted.
+    # This is a string showing which badges in which worksheets have been earned. The format is "X:Y" where X is the
+    # worksheet ID and Y is the badge ID. This repeats for all badges and each pair is comma-separated.
+    aimmo_badges = models.CharField(max_length=200, null=True, blank=True)
+
     def __str__(self):
         return f"{self.user.first_name} {self.user.last_name}"
 
@@ -232,10 +237,7 @@ class StudentModelManager(models.Manager):
         user_profile = UserProfile.objects.create(user=user)
 
         return Student.objects.create(
-            class_field=klass,
-            user=user_profile,
-            new_user=user,
-            login_id=login_id,
+            class_field=klass, user=user_profile, new_user=user, login_id=login_id
         )
 
     def independentStudentFactory(self, name, email, password):
